message

package
v0.0.0-...-d2e3589 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 22, 2023 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the message type in the database.
	Label = "message"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldChannelID holds the string denoting the channel_id field in the database.
	FieldChannelID = "channel_id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldSequence holds the string denoting the sequence field in the database.
	FieldSequence = "sequence"
	// FieldHeader holds the string denoting the header field in the database.
	FieldHeader = "header"
	// FieldContent holds the string denoting the content field in the database.
	FieldContent = "content"
	// EdgeAuthor holds the string denoting the author edge name in mutations.
	EdgeAuthor = "author"
	// EdgeChannel holds the string denoting the channel edge name in mutations.
	EdgeChannel = "channel"
	// EdgeMessageRecipients holds the string denoting the message_recipients edge name in mutations.
	EdgeMessageRecipients = "message_recipients"
	// EdgeRecipients holds the string denoting the recipients edge name in mutations.
	EdgeRecipients = "recipients"
	// Table holds the table name of the message in the database.
	Table = "messages"
	// AuthorTable is the table that holds the author relation/edge.
	AuthorTable = "messages"
	// AuthorInverseTable is the table name for the User entity.
	// It exists in this package in order to avoid circular dependency with the "user" package.
	AuthorInverseTable = "users"
	// AuthorColumn is the table column denoting the author relation/edge.
	AuthorColumn = "user_messages"
	// ChannelTable is the table that holds the channel relation/edge.
	ChannelTable = "messages"
	// ChannelInverseTable is the table name for the Channel entity.
	// It exists in this package in order to avoid circular dependency with the "channel" package.
	ChannelInverseTable = "channels"
	// ChannelColumn is the table column denoting the channel relation/edge.
	ChannelColumn = "channel_id"
	// MessageRecipientsTable is the table that holds the message_recipients relation/edge. The primary key declared below.
	MessageRecipientsTable = "recipients"
	// MessageRecipientsInverseTable is the table name for the User entity.
	// It exists in this package in order to avoid circular dependency with the "user" package.
	MessageRecipientsInverseTable = "users"
	// RecipientsTable is the table that holds the recipients relation/edge.
	RecipientsTable = "recipients"
	// RecipientsInverseTable is the table name for the Recipient entity.
	// It exists in this package in order to avoid circular dependency with the "recipient" package.
	RecipientsInverseTable = "recipients"
	// RecipientsColumn is the table column denoting the recipients relation/edge.
	RecipientsColumn = "message_id"
)

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
)

Columns holds all SQL columns for message fields.

var ForeignKeys = []string{
	"user_messages",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "messages" table and are not defined as standalone fields in the schema.

var (
	// MessageRecipientsPrimaryKey and MessageRecipientsColumn2 are the table columns denoting the
	// primary key for the message_recipients relation (M2M).
	MessageRecipientsPrimaryKey = []string{"user_id", "message_id"}
)

Functions

func And

func And(predicates ...predicate.Message) predicate.Message

And groups predicates with the AND operator between them.

func ChannelID

func ChannelID(v uuid.UUID) predicate.Message

ChannelID applies equality check predicate on the "channel_id" field. It's identical to ChannelIDEQ.

func ChannelIDEQ

func ChannelIDEQ(v uuid.UUID) predicate.Message

ChannelIDEQ applies the EQ predicate on the "channel_id" field.

func ChannelIDIn

func ChannelIDIn(vs ...uuid.UUID) predicate.Message

ChannelIDIn applies the In predicate on the "channel_id" field.

func ChannelIDNEQ

func ChannelIDNEQ(v uuid.UUID) predicate.Message

ChannelIDNEQ applies the NEQ predicate on the "channel_id" field.

func ChannelIDNotIn

func ChannelIDNotIn(vs ...uuid.UUID) predicate.Message

ChannelIDNotIn applies the NotIn predicate on the "channel_id" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.Message

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Message

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Message

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Message

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Message

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Message

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Message

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Message

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Message

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func HasAuthor

func HasAuthor() predicate.Message

HasAuthor applies the HasEdge predicate on the "author" edge.

func HasAuthorWith

func HasAuthorWith(preds ...predicate.User) predicate.Message

HasAuthorWith applies the HasEdge predicate on the "author" edge with a given conditions (other predicates).

func HasChannel

func HasChannel() predicate.Message

HasChannel applies the HasEdge predicate on the "channel" edge.

func HasChannelWith

func HasChannelWith(preds ...predicate.Channel) predicate.Message

HasChannelWith applies the HasEdge predicate on the "channel" edge with a given conditions (other predicates).

func HasMessageRecipients

func HasMessageRecipients() predicate.Message

HasMessageRecipients applies the HasEdge predicate on the "message_recipients" edge.

func HasMessageRecipientsWith

func HasMessageRecipientsWith(preds ...predicate.User) predicate.Message

HasMessageRecipientsWith applies the HasEdge predicate on the "message_recipients" edge with a given conditions (other predicates).

func HasRecipients

func HasRecipients() predicate.Message

HasRecipients applies the HasEdge predicate on the "recipients" edge.

func HasRecipientsWith

func HasRecipientsWith(preds ...predicate.Recipient) predicate.Message

HasRecipientsWith applies the HasEdge predicate on the "recipients" edge with a given conditions (other predicates).

func ID

func ID(id uuid.UUID) predicate.Message

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Message

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Message

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Message

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Message

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Message

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Message

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Message

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Message

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Message) predicate.Message

Or groups predicates with the OR operator between them.

func Sequence

func Sequence(v int) predicate.Message

Sequence applies equality check predicate on the "sequence" field. It's identical to SequenceEQ.

func SequenceEQ

func SequenceEQ(v int) predicate.Message

SequenceEQ applies the EQ predicate on the "sequence" field.

func SequenceGT

func SequenceGT(v int) predicate.Message

SequenceGT applies the GT predicate on the "sequence" field.

func SequenceGTE

func SequenceGTE(v int) predicate.Message

SequenceGTE applies the GTE predicate on the "sequence" field.

func SequenceIn

func SequenceIn(vs ...int) predicate.Message

SequenceIn applies the In predicate on the "sequence" field.

func SequenceLT

func SequenceLT(v int) predicate.Message

SequenceLT applies the LT predicate on the "sequence" field.

func SequenceLTE

func SequenceLTE(v int) predicate.Message

SequenceLTE applies the LTE predicate on the "sequence" field.

func SequenceNEQ

func SequenceNEQ(v int) predicate.Message

SequenceNEQ applies the NEQ predicate on the "sequence" field.

func SequenceNotIn

func SequenceNotIn(vs ...int) predicate.Message

SequenceNotIn applies the NotIn predicate on the "sequence" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Message

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Message

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Message

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Message

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Message

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Message

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Message

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Message

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Message

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

This section is empty.

Jump to