schema

package
v0.0.0-...-d2e3589 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 22, 2023 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Channel

type Channel struct {
	ent.Schema
}

Channel holds the schema definition for the Channel entity.

func (Channel) Edges

func (Channel) Edges() []ent.Edge

Edges of the Channel.

func (Channel) Fields

func (Channel) Fields() []ent.Field

Fields of the Channel.

type Device

type Device struct {
	ent.Schema
}

Device holds the schema definition for the Device entity.

func (Device) Edges

func (Device) Edges() []ent.Edge

Edges of the Device.

func (Device) Fields

func (Device) Fields() []ent.Field

Fields of the Device.

func (Device) Indexes

func (Device) Indexes() []ent.Index

Indexes of the Device.

type Message

type Message struct {
	ent.Schema
}

Message holds the schema definition for the Message entity.

func (Message) Edges

func (Message) Edges() []ent.Edge

Edges of the Message.

func (Message) Fields

func (Message) Fields() []ent.Field

Fields of the Message.

func (Message) Indexes

func (Message) Indexes() []ent.Index

Indexes of the Subscription.

type MessageContent

type MessageContent struct {
	Text string `json:"text"`
}

type MessageHeaders

type MessageHeaders struct{}

type Recipient

type Recipient struct {
	ent.Schema
}

Recipient holds the schema definition for the Recipient entity.

func (Recipient) Annotations

func (Recipient) Annotations() []schema.Annotation

Annotations of the schema

func (Recipient) Edges

func (Recipient) Edges() []ent.Edge

Edges of the Recipient.

func (Recipient) Fields

func (Recipient) Fields() []ent.Field

Fields of the Recipient.

type Subscription

type Subscription struct {
	ent.Schema
}

Subscription holds the schema definition for the Subscription entity.

func (Subscription) Edges

func (Subscription) Edges() []ent.Edge

Edges of the Subscription.

func (Subscription) Fields

func (Subscription) Fields() []ent.Field

Fields of the Subscription.

type User

type User struct {
	ent.Schema
}

User holds the schema definition for the User entity.

func (User) Edges

func (User) Edges() []ent.Edge

Edges of the User.

func (User) Fields

func (User) Fields() []ent.Field

Fields of the User.

Jump to