Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Message) predicate.Message
- func ChannelID(v uuid.UUID) predicate.Message
- func ChannelIDEQ(v uuid.UUID) predicate.Message
- func ChannelIDIn(vs ...uuid.UUID) predicate.Message
- func ChannelIDNEQ(v uuid.UUID) predicate.Message
- func ChannelIDNotIn(vs ...uuid.UUID) predicate.Message
- func CreatedAt(v time.Time) predicate.Message
- func CreatedAtEQ(v time.Time) predicate.Message
- func CreatedAtGT(v time.Time) predicate.Message
- func CreatedAtGTE(v time.Time) predicate.Message
- func CreatedAtIn(vs ...time.Time) predicate.Message
- func CreatedAtLT(v time.Time) predicate.Message
- func CreatedAtLTE(v time.Time) predicate.Message
- func CreatedAtNEQ(v time.Time) predicate.Message
- func CreatedAtNotIn(vs ...time.Time) predicate.Message
- func HasAuthor() predicate.Message
- func HasAuthorWith(preds ...predicate.User) predicate.Message
- func HasChannel() predicate.Message
- func HasChannelWith(preds ...predicate.Channel) predicate.Message
- func HasMessageRecipients() predicate.Message
- func HasMessageRecipientsWith(preds ...predicate.User) predicate.Message
- func HasRecipients() predicate.Message
- func HasRecipientsWith(preds ...predicate.Recipient) predicate.Message
- func ID(id uuid.UUID) predicate.Message
- func IDEQ(id uuid.UUID) predicate.Message
- func IDGT(id uuid.UUID) predicate.Message
- func IDGTE(id uuid.UUID) predicate.Message
- func IDIn(ids ...uuid.UUID) predicate.Message
- func IDLT(id uuid.UUID) predicate.Message
- func IDLTE(id uuid.UUID) predicate.Message
- func IDNEQ(id uuid.UUID) predicate.Message
- func IDNotIn(ids ...uuid.UUID) predicate.Message
- func Not(p predicate.Message) predicate.Message
- func Or(predicates ...predicate.Message) predicate.Message
- func Sequence(v int) predicate.Message
- func SequenceEQ(v int) predicate.Message
- func SequenceGT(v int) predicate.Message
- func SequenceGTE(v int) predicate.Message
- func SequenceIn(vs ...int) predicate.Message
- func SequenceLT(v int) predicate.Message
- func SequenceLTE(v int) predicate.Message
- func SequenceNEQ(v int) predicate.Message
- func SequenceNotIn(vs ...int) predicate.Message
- func UpdatedAt(v time.Time) predicate.Message
- func UpdatedAtEQ(v time.Time) predicate.Message
- func UpdatedAtGT(v time.Time) predicate.Message
- func UpdatedAtGTE(v time.Time) predicate.Message
- func UpdatedAtIn(vs ...time.Time) predicate.Message
- func UpdatedAtLT(v time.Time) predicate.Message
- func UpdatedAtLTE(v time.Time) predicate.Message
- func UpdatedAtNEQ(v time.Time) predicate.Message
- func UpdatedAtNotIn(vs ...time.Time) predicate.Message
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the message type in the database. Label = "message" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldChannelID holds the string denoting the channel_id field in the database. FieldChannelID = "channel_id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldSequence holds the string denoting the sequence field in the database. FieldSequence = "sequence" // FieldHeader holds the string denoting the header field in the database. FieldHeader = "header" // FieldContent holds the string denoting the content field in the database. FieldContent = "content" // EdgeAuthor holds the string denoting the author edge name in mutations. EdgeAuthor = "author" // EdgeChannel holds the string denoting the channel edge name in mutations. EdgeChannel = "channel" // EdgeMessageRecipients holds the string denoting the message_recipients edge name in mutations. EdgeMessageRecipients = "message_recipients" // EdgeRecipients holds the string denoting the recipients edge name in mutations. EdgeRecipients = "recipients" // Table holds the table name of the message in the database. Table = "messages" // AuthorTable is the table that holds the author relation/edge. AuthorTable = "messages" // AuthorInverseTable is the table name for the User entity. // It exists in this package in order to avoid circular dependency with the "user" package. AuthorInverseTable = "users" // AuthorColumn is the table column denoting the author relation/edge. AuthorColumn = "user_messages" // ChannelTable is the table that holds the channel relation/edge. ChannelTable = "messages" // ChannelInverseTable is the table name for the Channel entity. // It exists in this package in order to avoid circular dependency with the "channel" package. ChannelInverseTable = "channels" // ChannelColumn is the table column denoting the channel relation/edge. ChannelColumn = "channel_id" // MessageRecipientsTable is the table that holds the message_recipients relation/edge. The primary key declared below. MessageRecipientsTable = "recipients" // MessageRecipientsInverseTable is the table name for the User entity. // It exists in this package in order to avoid circular dependency with the "user" package. MessageRecipientsInverseTable = "users" // RecipientsTable is the table that holds the recipients relation/edge. RecipientsTable = "recipients" // RecipientsInverseTable is the table name for the Recipient entity. // It exists in this package in order to avoid circular dependency with the "recipient" package. RecipientsInverseTable = "recipients" // RecipientsColumn is the table column denoting the recipients relation/edge. RecipientsColumn = "message_id" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time )
var Columns = []string{ FieldID, FieldChannelID, FieldCreatedAt, FieldUpdatedAt, FieldSequence, FieldHeader, FieldContent, }
Columns holds all SQL columns for message fields.
var ForeignKeys = []string{
"user_messages",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "messages" table and are not defined as standalone fields in the schema.
var ( // MessageRecipientsPrimaryKey and MessageRecipientsColumn2 are the table columns denoting the // primary key for the message_recipients relation (M2M). MessageRecipientsPrimaryKey = []string{"user_id", "message_id"} )
Functions ¶
func ChannelID ¶
ChannelID applies equality check predicate on the "channel_id" field. It's identical to ChannelIDEQ.
func ChannelIDEQ ¶
ChannelIDEQ applies the EQ predicate on the "channel_id" field.
func ChannelIDIn ¶
ChannelIDIn applies the In predicate on the "channel_id" field.
func ChannelIDNEQ ¶
ChannelIDNEQ applies the NEQ predicate on the "channel_id" field.
func ChannelIDNotIn ¶
ChannelIDNotIn applies the NotIn predicate on the "channel_id" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func HasAuthorWith ¶
HasAuthorWith applies the HasEdge predicate on the "author" edge with a given conditions (other predicates).
func HasChannel ¶
HasChannel applies the HasEdge predicate on the "channel" edge.
func HasChannelWith ¶
HasChannelWith applies the HasEdge predicate on the "channel" edge with a given conditions (other predicates).
func HasMessageRecipients ¶
HasMessageRecipients applies the HasEdge predicate on the "message_recipients" edge.
func HasMessageRecipientsWith ¶
HasMessageRecipientsWith applies the HasEdge predicate on the "message_recipients" edge with a given conditions (other predicates).
func HasRecipients ¶
HasRecipients applies the HasEdge predicate on the "recipients" edge.
func HasRecipientsWith ¶
HasRecipientsWith applies the HasEdge predicate on the "recipients" edge with a given conditions (other predicates).
func Sequence ¶
Sequence applies equality check predicate on the "sequence" field. It's identical to SequenceEQ.
func SequenceEQ ¶
SequenceEQ applies the EQ predicate on the "sequence" field.
func SequenceGT ¶
SequenceGT applies the GT predicate on the "sequence" field.
func SequenceGTE ¶
SequenceGTE applies the GTE predicate on the "sequence" field.
func SequenceIn ¶
SequenceIn applies the In predicate on the "sequence" field.
func SequenceLT ¶
SequenceLT applies the LT predicate on the "sequence" field.
func SequenceLTE ¶
SequenceLTE applies the LTE predicate on the "sequence" field.
func SequenceNEQ ¶
SequenceNEQ applies the NEQ predicate on the "sequence" field.
func SequenceNotIn ¶
SequenceNotIn applies the NotIn predicate on the "sequence" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.