Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MessageContent ¶
type MessageContent struct {
Text string `json:"text"`
}
type MessageHeaders ¶
type MessageHeaders struct{}
type Recipient ¶
Recipient holds the schema definition for the Recipient entity.
func (Recipient) Annotations ¶
func (Recipient) Annotations() []schema.Annotation
Annotations of the schema
type Subscription ¶
Subscription holds the schema definition for the Subscription entity.
Click to show internal directories.
Click to hide internal directories.