Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Subscription) predicate.Subscription
- func ChannelID(v uuid.UUID) predicate.Subscription
- func ChannelIDEQ(v uuid.UUID) predicate.Subscription
- func ChannelIDIn(vs ...uuid.UUID) predicate.Subscription
- func ChannelIDNEQ(v uuid.UUID) predicate.Subscription
- func ChannelIDNotIn(vs ...uuid.UUID) predicate.Subscription
- func HasChannel() predicate.Subscription
- func HasChannelWith(preds ...predicate.Channel) predicate.Subscription
- func HasUser() predicate.Subscription
- func HasUserWith(preds ...predicate.User) predicate.Subscription
- func ID(id uuid.UUID) predicate.Subscription
- func IDEQ(id uuid.UUID) predicate.Subscription
- func IDGT(id uuid.UUID) predicate.Subscription
- func IDGTE(id uuid.UUID) predicate.Subscription
- func IDIn(ids ...uuid.UUID) predicate.Subscription
- func IDLT(id uuid.UUID) predicate.Subscription
- func IDLTE(id uuid.UUID) predicate.Subscription
- func IDNEQ(id uuid.UUID) predicate.Subscription
- func IDNotIn(ids ...uuid.UUID) predicate.Subscription
- func Not(p predicate.Subscription) predicate.Subscription
- func Or(predicates ...predicate.Subscription) predicate.Subscription
- func Pinned(v bool) predicate.Subscription
- func PinnedAt(v time.Time) predicate.Subscription
- func PinnedAtEQ(v time.Time) predicate.Subscription
- func PinnedAtGT(v time.Time) predicate.Subscription
- func PinnedAtGTE(v time.Time) predicate.Subscription
- func PinnedAtIn(vs ...time.Time) predicate.Subscription
- func PinnedAtIsNil() predicate.Subscription
- func PinnedAtLT(v time.Time) predicate.Subscription
- func PinnedAtLTE(v time.Time) predicate.Subscription
- func PinnedAtNEQ(v time.Time) predicate.Subscription
- func PinnedAtNotIn(vs ...time.Time) predicate.Subscription
- func PinnedAtNotNil() predicate.Subscription
- func PinnedEQ(v bool) predicate.Subscription
- func PinnedIsNil() predicate.Subscription
- func PinnedNEQ(v bool) predicate.Subscription
- func PinnedNotNil() predicate.Subscription
- func Role(v string) predicate.Subscription
- func RoleContains(v string) predicate.Subscription
- func RoleContainsFold(v string) predicate.Subscription
- func RoleEQ(v string) predicate.Subscription
- func RoleEqualFold(v string) predicate.Subscription
- func RoleGT(v string) predicate.Subscription
- func RoleGTE(v string) predicate.Subscription
- func RoleHasPrefix(v string) predicate.Subscription
- func RoleHasSuffix(v string) predicate.Subscription
- func RoleIn(vs ...string) predicate.Subscription
- func RoleLT(v string) predicate.Subscription
- func RoleLTE(v string) predicate.Subscription
- func RoleNEQ(v string) predicate.Subscription
- func RoleNotIn(vs ...string) predicate.Subscription
- func Status(v string) predicate.Subscription
- func StatusContains(v string) predicate.Subscription
- func StatusContainsFold(v string) predicate.Subscription
- func StatusEQ(v string) predicate.Subscription
- func StatusEqualFold(v string) predicate.Subscription
- func StatusGT(v string) predicate.Subscription
- func StatusGTE(v string) predicate.Subscription
- func StatusHasPrefix(v string) predicate.Subscription
- func StatusHasSuffix(v string) predicate.Subscription
- func StatusIn(vs ...string) predicate.Subscription
- func StatusLT(v string) predicate.Subscription
- func StatusLTE(v string) predicate.Subscription
- func StatusNEQ(v string) predicate.Subscription
- func StatusNotIn(vs ...string) predicate.Subscription
- func UserID(v uuid.UUID) predicate.Subscription
- func UserIDEQ(v uuid.UUID) predicate.Subscription
- func UserIDIn(vs ...uuid.UUID) predicate.Subscription
- func UserIDNEQ(v uuid.UUID) predicate.Subscription
- func UserIDNotIn(vs ...uuid.UUID) predicate.Subscription
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the subscription type in the database. Label = "subscription" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldChannelID holds the string denoting the channel_id field in the database. FieldChannelID = "channel_id" // FieldUserID holds the string denoting the user_id field in the database. FieldUserID = "user_id" // FieldRole holds the string denoting the role field in the database. FieldRole = "role" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // FieldPinned holds the string denoting the pinned field in the database. FieldPinned = "pinned" // FieldPinnedAt holds the string denoting the pinned_at field in the database. FieldPinnedAt = "pinned_at" // EdgeUser holds the string denoting the user edge name in mutations. EdgeUser = "user" // EdgeChannel holds the string denoting the channel edge name in mutations. EdgeChannel = "channel" // Table holds the table name of the subscription in the database. Table = "subscriptions" // UserTable is the table that holds the user relation/edge. UserTable = "subscriptions" // UserInverseTable is the table name for the User entity. // It exists in this package in order to avoid circular dependency with the "user" package. UserInverseTable = "users" // UserColumn is the table column denoting the user relation/edge. UserColumn = "user_id" // ChannelTable is the table that holds the channel relation/edge. ChannelTable = "subscriptions" // ChannelInverseTable is the table name for the Channel entity. // It exists in this package in order to avoid circular dependency with the "channel" package. ChannelInverseTable = "channels" // ChannelColumn is the table column denoting the channel relation/edge. ChannelColumn = "channel_id" )
Variables ¶
var Columns = []string{ FieldID, FieldChannelID, FieldUserID, FieldRole, FieldStatus, FieldPinned, FieldPinnedAt, }
Columns holds all SQL columns for subscription fields.
Functions ¶
func And ¶
func And(predicates ...predicate.Subscription) predicate.Subscription
And groups predicates with the AND operator between them.
func ChannelID ¶
func ChannelID(v uuid.UUID) predicate.Subscription
ChannelID applies equality check predicate on the "channel_id" field. It's identical to ChannelIDEQ.
func ChannelIDEQ ¶
func ChannelIDEQ(v uuid.UUID) predicate.Subscription
ChannelIDEQ applies the EQ predicate on the "channel_id" field.
func ChannelIDIn ¶
func ChannelIDIn(vs ...uuid.UUID) predicate.Subscription
ChannelIDIn applies the In predicate on the "channel_id" field.
func ChannelIDNEQ ¶
func ChannelIDNEQ(v uuid.UUID) predicate.Subscription
ChannelIDNEQ applies the NEQ predicate on the "channel_id" field.
func ChannelIDNotIn ¶
func ChannelIDNotIn(vs ...uuid.UUID) predicate.Subscription
ChannelIDNotIn applies the NotIn predicate on the "channel_id" field.
func HasChannel ¶
func HasChannel() predicate.Subscription
HasChannel applies the HasEdge predicate on the "channel" edge.
func HasChannelWith ¶
func HasChannelWith(preds ...predicate.Channel) predicate.Subscription
HasChannelWith applies the HasEdge predicate on the "channel" edge with a given conditions (other predicates).
func HasUser ¶
func HasUser() predicate.Subscription
HasUser applies the HasEdge predicate on the "user" edge.
func HasUserWith ¶
func HasUserWith(preds ...predicate.User) predicate.Subscription
HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).
func IDEQ ¶
func IDEQ(id uuid.UUID) predicate.Subscription
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id uuid.UUID) predicate.Subscription
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id uuid.UUID) predicate.Subscription
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...uuid.UUID) predicate.Subscription
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id uuid.UUID) predicate.Subscription
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id uuid.UUID) predicate.Subscription
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id uuid.UUID) predicate.Subscription
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...uuid.UUID) predicate.Subscription
IDNotIn applies the NotIn predicate on the ID field.
func Not ¶
func Not(p predicate.Subscription) predicate.Subscription
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.Subscription) predicate.Subscription
Or groups predicates with the OR operator between them.
func Pinned ¶
func Pinned(v bool) predicate.Subscription
Pinned applies equality check predicate on the "pinned" field. It's identical to PinnedEQ.
func PinnedAt ¶
func PinnedAt(v time.Time) predicate.Subscription
PinnedAt applies equality check predicate on the "pinned_at" field. It's identical to PinnedAtEQ.
func PinnedAtEQ ¶
func PinnedAtEQ(v time.Time) predicate.Subscription
PinnedAtEQ applies the EQ predicate on the "pinned_at" field.
func PinnedAtGT ¶
func PinnedAtGT(v time.Time) predicate.Subscription
PinnedAtGT applies the GT predicate on the "pinned_at" field.
func PinnedAtGTE ¶
func PinnedAtGTE(v time.Time) predicate.Subscription
PinnedAtGTE applies the GTE predicate on the "pinned_at" field.
func PinnedAtIn ¶
func PinnedAtIn(vs ...time.Time) predicate.Subscription
PinnedAtIn applies the In predicate on the "pinned_at" field.
func PinnedAtIsNil ¶
func PinnedAtIsNil() predicate.Subscription
PinnedAtIsNil applies the IsNil predicate on the "pinned_at" field.
func PinnedAtLT ¶
func PinnedAtLT(v time.Time) predicate.Subscription
PinnedAtLT applies the LT predicate on the "pinned_at" field.
func PinnedAtLTE ¶
func PinnedAtLTE(v time.Time) predicate.Subscription
PinnedAtLTE applies the LTE predicate on the "pinned_at" field.
func PinnedAtNEQ ¶
func PinnedAtNEQ(v time.Time) predicate.Subscription
PinnedAtNEQ applies the NEQ predicate on the "pinned_at" field.
func PinnedAtNotIn ¶
func PinnedAtNotIn(vs ...time.Time) predicate.Subscription
PinnedAtNotIn applies the NotIn predicate on the "pinned_at" field.
func PinnedAtNotNil ¶
func PinnedAtNotNil() predicate.Subscription
PinnedAtNotNil applies the NotNil predicate on the "pinned_at" field.
func PinnedEQ ¶
func PinnedEQ(v bool) predicate.Subscription
PinnedEQ applies the EQ predicate on the "pinned" field.
func PinnedIsNil ¶
func PinnedIsNil() predicate.Subscription
PinnedIsNil applies the IsNil predicate on the "pinned" field.
func PinnedNEQ ¶
func PinnedNEQ(v bool) predicate.Subscription
PinnedNEQ applies the NEQ predicate on the "pinned" field.
func PinnedNotNil ¶
func PinnedNotNil() predicate.Subscription
PinnedNotNil applies the NotNil predicate on the "pinned" field.
func Role ¶
func Role(v string) predicate.Subscription
Role applies equality check predicate on the "role" field. It's identical to RoleEQ.
func RoleContains ¶
func RoleContains(v string) predicate.Subscription
RoleContains applies the Contains predicate on the "role" field.
func RoleContainsFold ¶
func RoleContainsFold(v string) predicate.Subscription
RoleContainsFold applies the ContainsFold predicate on the "role" field.
func RoleEQ ¶
func RoleEQ(v string) predicate.Subscription
RoleEQ applies the EQ predicate on the "role" field.
func RoleEqualFold ¶
func RoleEqualFold(v string) predicate.Subscription
RoleEqualFold applies the EqualFold predicate on the "role" field.
func RoleGT ¶
func RoleGT(v string) predicate.Subscription
RoleGT applies the GT predicate on the "role" field.
func RoleGTE ¶
func RoleGTE(v string) predicate.Subscription
RoleGTE applies the GTE predicate on the "role" field.
func RoleHasPrefix ¶
func RoleHasPrefix(v string) predicate.Subscription
RoleHasPrefix applies the HasPrefix predicate on the "role" field.
func RoleHasSuffix ¶
func RoleHasSuffix(v string) predicate.Subscription
RoleHasSuffix applies the HasSuffix predicate on the "role" field.
func RoleIn ¶
func RoleIn(vs ...string) predicate.Subscription
RoleIn applies the In predicate on the "role" field.
func RoleLT ¶
func RoleLT(v string) predicate.Subscription
RoleLT applies the LT predicate on the "role" field.
func RoleLTE ¶
func RoleLTE(v string) predicate.Subscription
RoleLTE applies the LTE predicate on the "role" field.
func RoleNEQ ¶
func RoleNEQ(v string) predicate.Subscription
RoleNEQ applies the NEQ predicate on the "role" field.
func RoleNotIn ¶
func RoleNotIn(vs ...string) predicate.Subscription
RoleNotIn applies the NotIn predicate on the "role" field.
func Status ¶
func Status(v string) predicate.Subscription
Status applies equality check predicate on the "status" field. It's identical to StatusEQ.
func StatusContains ¶
func StatusContains(v string) predicate.Subscription
StatusContains applies the Contains predicate on the "status" field.
func StatusContainsFold ¶
func StatusContainsFold(v string) predicate.Subscription
StatusContainsFold applies the ContainsFold predicate on the "status" field.
func StatusEQ ¶
func StatusEQ(v string) predicate.Subscription
StatusEQ applies the EQ predicate on the "status" field.
func StatusEqualFold ¶
func StatusEqualFold(v string) predicate.Subscription
StatusEqualFold applies the EqualFold predicate on the "status" field.
func StatusGT ¶
func StatusGT(v string) predicate.Subscription
StatusGT applies the GT predicate on the "status" field.
func StatusGTE ¶
func StatusGTE(v string) predicate.Subscription
StatusGTE applies the GTE predicate on the "status" field.
func StatusHasPrefix ¶
func StatusHasPrefix(v string) predicate.Subscription
StatusHasPrefix applies the HasPrefix predicate on the "status" field.
func StatusHasSuffix ¶
func StatusHasSuffix(v string) predicate.Subscription
StatusHasSuffix applies the HasSuffix predicate on the "status" field.
func StatusIn ¶
func StatusIn(vs ...string) predicate.Subscription
StatusIn applies the In predicate on the "status" field.
func StatusLT ¶
func StatusLT(v string) predicate.Subscription
StatusLT applies the LT predicate on the "status" field.
func StatusLTE ¶
func StatusLTE(v string) predicate.Subscription
StatusLTE applies the LTE predicate on the "status" field.
func StatusNEQ ¶
func StatusNEQ(v string) predicate.Subscription
StatusNEQ applies the NEQ predicate on the "status" field.
func StatusNotIn ¶
func StatusNotIn(vs ...string) predicate.Subscription
StatusNotIn applies the NotIn predicate on the "status" field.
func UserID ¶
func UserID(v uuid.UUID) predicate.Subscription
UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.
func UserIDEQ ¶
func UserIDEQ(v uuid.UUID) predicate.Subscription
UserIDEQ applies the EQ predicate on the "user_id" field.
func UserIDIn ¶
func UserIDIn(vs ...uuid.UUID) predicate.Subscription
UserIDIn applies the In predicate on the "user_id" field.
func UserIDNEQ ¶
func UserIDNEQ(v uuid.UUID) predicate.Subscription
UserIDNEQ applies the NEQ predicate on the "user_id" field.
func UserIDNotIn ¶
func UserIDNotIn(vs ...uuid.UUID) predicate.Subscription
UserIDNotIn applies the NotIn predicate on the "user_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.